@@ -1,5 +1,8 @@
 #ifndef GCC_TM_H
 #define GCC_TM_H
+#ifndef OR1K_DELAY_DEFAULT
+# define OR1K_DELAY_DEFAULT OR1K_DELAY_ON
+#endif
 #ifndef LIBC_GLIBC
 # define LIBC_GLIBC 1
 #endif
@@ -9,25 +12,23 @@
 #ifndef LIBC_BIONIC
 # define LIBC_BIONIC 3
 #endif
+#ifndef LIBC_MUSL
+# define LIBC_MUSL 4
+#endif
 #ifndef DEFAULT_LIBC
 # define DEFAULT_LIBC LIBC_GLIBC
 #endif
 #ifndef ANDROID_DEFAULT
 # define ANDROID_DEFAULT 0
 #endif
-#ifndef OR1K_DELAY_DEFAULT
-# define OR1K_DELAY_DEFAULT OR1K_DELAY_ON
-#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
 # include "config/or1k/or1k.h"
 # include "config/dbxelf.h"
 # include "config/elfos.h"
-# include "config/or1k/elf.h"
 # include "config/gnu-user.h"
 # include "config/linux.h"
-# include "config/or1k/linux-gas.h"
 # include "config/or1k/linux-elf.h"
 # include "config/uclibc-stdint.h"
 # include "config/initfini-array.h"
